{**
 * 2007-2019 PrestaShop and Contributors
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2019 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 * International Registered Trademark & Property of PrestaShop SA
 *}
{block name='order_products_table'}
  <div class="box hidden sm:block">
    <table id="order-products" class="table-auto border-separate border border-gray-200 w-full">
      <thead class="bg-gray-100">
        <tr>
          <th class="px-4 py-2 text-left">{l s='Product' d='Shop.Theme.Catalog'}</th>
          <th class="px-4 py-2 text-left">{l s='Quantity' d='Shop.Theme.Catalog'}</th>
          <th class="px-4 py-2 text-left">{l s='Unit price' d='Shop.Theme.Catalog'}</th>
          <th class="px-4 py-2 text-left">{l s='Total price' d='Shop.Theme.Catalog'}</th>
        </tr>
      </thead>
      {foreach from=$order.products item=product}
        <tr class="border-t border-gray-200">
          <td class="px-4 py-2">
            <strong>
              <a {if isset($product.download_link)}href="{$product.download_link}"{/if} class="text-blue-600 hover:underline">
                {$product.name}
              </a>
            </strong><br/>
            {if $product.reference}
              <span class="text-sm text-gray-500">{l s='Reference' d='Shop.Theme.Catalog'}: {$product.reference}<br/></span>
            {/if}
            {if $product.customizations}
              {foreach from=$product.customizations item="customization"}
                <div class="customization mt-2">
                  <a href="#" data-toggle="modal" data-target="#product-customizations-modal-{$customization.id_customization}" class="text-blue-600 hover:underline">{l s='Product customization' d='Shop.Theme.Catalog'}</a>
                </div>
                <div id="_desktop_product_customization_modal_wrapper_{$customization.id_customization}">
                  <div class="modal fade customization-modal" id="product-customizations-modal-{$customization.id_customization}" tabindex="-1" role="dialog" aria-hidden="true">
                    <div class="modal-dialog" role="document">
                      <div class="modal-content">
                        <div class="modal-header">
                          <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                          </button>
                          <h4 class="modal-title">{l s='Product customization' d='Shop.Theme.Catalog'}</h4>
                        </div>
                        <div class="modal-body">
                          {foreach from=$customization.fields item="field"}
                            <div class="product-customization-line flex mb-2">
                              <div class="w-1/3 font-semibold text-sm text-gray-600">
                                {$field.label}
                              </div>
                              <div class="w-2/3 text-sm">
                                {if $field.type == 'text'}
                                  {if (int)$field.id_module}
                                    {$field.text nofilter}
                                  {else}
                                    {$field.text}
                                  {/if}
                                {elseif $field.type == 'image'}
                                  <img src="{$field.image.small.url}" class="w-16 h-16 object-cover">
                                {/if}
                              </div>
                            </div>
                          {/foreach}
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              {/foreach}
            {/if}
          </td>
          <td class="px-4 py-2">
            {if $product.customizations}
              {foreach $product.customizations as $customization}
                {$customization.quantity}
              {/foreach}
            {else}
              {$product.quantity}
            {/if}
          </td>
          <td class="px-4 py-2 text-right">{$|cat:$product.price}</td>
          <td class="px-4 py-2 text-right">{$|cat:$product.total}</td>
        </tr>
      {/foreach}
      <tfoot>
        {foreach $order.subtotals as $line}
          {if $line.value}
            <tr class="text-right border-t border-gray-200">
              <td colspan="3" class="px-4 py-2">{$line.label}</td>
              <td class="px-4 py-2">{$line.value}</td>
            </tr>
          {/if}
        {/foreach}
        <tr class="text-right border-t border-gray-200">
          <td colspan="3" class="px-4 py-2">{$order.totals.total.label}</td>
          <td class="px-4 py-2">{$order.totals.total.value}</td>
        </tr>
      </tfoot>
    </table>
  </div>

  <div class="order-items sm:hidden box">
    {foreach from=$order.products item=product}
      <div class="order-item py-4 border-b border-gray-200">
        <div class="flex">
          <div class="w-1/2">
            <div class="text-lg font-semibold">{$product.name}</div>
            {if $product.reference}
              <div class="text-sm text-gray-500">{l s='Reference' d='Shop.Theme.Catalog'}: {$product.reference}</div>
            {/if}
            {if $product.customizations}
              {foreach $product.customizations as $customization}
                <div class="customization mt-2">
                  <a href="#" data-toggle="modal" data-target="#product-customizations-modal-{$customization.id_customization}" class="text-blue-600 hover:underline">{l s='Product customization' d='Shop.Theme.Catalog'}</a>
                </div>
                <div id="_mobile_product_customization_modal_wrapper_{$customization.id_customization}"></div>
              {/foreach}
            {/if}
          </div>
          <div class="w-1/2 text-right">
            <div class="flex justify-between">
              <div class="text-sm">{$product.price}</div>
              <div class="text-sm">
                {if $product.customizations}
                  {foreach $product.customizations as $customization}
                    {$customization.quantity}
                  {/foreach}
                {else}
                  {$product.quantity}
                {/if}
              </div>
              <div class="text-sm">{'$'|cat:$product.total}</div>
            </div>
          </div>
        </div>
      </div>
    {/foreach}
  </div>

  <div class="order-totals sm:hidden box mt-4">
    {foreach $order.subtotals as $line}
      {if $line.value}
        <div class="order-total flex justify-between py-2">
          <div class="text-sm font-semibold">{'$line.label'}</div>
          <div class="text-sm">{'$line.value'}</div>
        </div>
      {/if}
    {/foreach}
    <div class="order-total flex justify-between py-2">
      <div class="text-sm font-semibold">{'$order.totals.total.label'}</div>
      <div class="text-sm">{'$order.totals.total.value'}</div>
    </div>
  </div>
{/block}
